======
Tacker
======

.. image:: https://governance.openstack.org/tc/badges/tacker.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

Welcome!
========

Tacker is an OpenStack based NFV Orchestrator service with built-in general
purpose VNF Manager to deploy and operate Virtual Network Functions (VNFs)
on an OpenStack based NFV Platform. It is based on ETSI MANO Architectural
Framework and provides a fully functional stack to orchestrate VNFs end-to-end.

Installation:
=============

Installation instructions and user guides can be found at:
https://docs.openstack.org/tacker/

Tacker code base supports OpenStack master and other releases. Please
follow the instructions in the above address for a successful installation of
corresponding release.

Code:
=====

Tacker code is available in following repositories:

* **Tacker server:** https://opendev.org/openstack/tacker
* **Tacker Python client:** https://opendev.org/openstack/python-tackerclient
* **Tacker Horizon UI:** https://opendev.org/openstack/tacker-horizon

Bugs:
=====

Please report bugs at: https://bugs.launchpad.net/tacker

External Resources:
===================

* Tacker Wiki: https://wiki.openstack.org/wiki/Tacker

* Tacker Blueprints: https://blueprints.launchpad.net/tacker

* For help on usage and hacking of Tacker, please send an email to
  OpenStack-dev Mailing List <mailto:openstack-discuss@lists.openstack.org>
  with **[openstack-dev] [Tacker]** tag.

* To get release notes: `Tacker Release Notes
  <https://docs.openstack.org/releasenotes/tacker/>`_
